# fast Na module

# Return kinetic parameters, constraints, and vector of volumes in each
# compartment (pL) (1 if gating variable, or in element corresponding to
# kappa)

# Translated from Pan 2018 cardiac AP 

import numpy as np

def kinetic_parameters(M, include_type2_reactions, dims, V):
    # Set the kinetic rate constants

    num_cols = dims['num_cols']
    num_rows = dims['num_rows']

    # constants are stored in V
    F = V['F']
    R = V['R']
    Cm = V['Cm']
    N_A = V['N_A']
    cKo = V['cKo']

    fkc = 1e6
    smr = 1e-3
    Km = 0.5e-3 # [ =] mM
    Vmax = 1.15 # [ =] uA / uF
    kcat = Vmax * Cm * 1e9 / (F * V['V_myo'])
    km = fkc
    kp = (km + kcat) / Km
    kf = [kp,    fkc]
    kr = [km,    smr]
    k_kinetic = kf + kr


    # CONSTRAINTS
    N_cT = []
    K_C = []

    # volume vector
    # W = list(np.append([1] * num_cols, [V['V_myo']] * num_rows))
    W = [1] * num_cols + [V['V_myo'], V['V_o'],V['V_myo'],V['V_myo']]

    return (k_kinetic, N_cT, K_C, W)













